==> vsn-backoffice-front-v0.0.33.zip: vsn-backoffice-front-v0.0.33/src/shared/sections/admin-config/infrastructure/lot/view/lot-list-view.tsx <==
"use client"

import { useMemo } from "react"
import { Stack, Typography } from "@mui/material"
import { HEADER } from "@/layouts/config-layout"
import TableControlBar from "@/shared/components/table/table-control-bar"
import type { LotList } from "@/shared/types/infrastructure"
import { type TabConfig, useTabsManager } from "@/hooks/use-tabs-manager"
import { TableType, TableColumn } from "@/shared/types/common"
import TabsCustom from "@/shared/components/tabs/tabs-custom"
import TableManager from "@/shared/components/table/table-manager"
import LotForm from "./lot-form"
import LotTableRow from "./lot-row"
import ConditionalComponent from "@/shared/components/table/ConditionalComponent"
import { UnsavedChangesDialog } from "@/shared/components/dialog/UnsavedChangesDialog"
import { useLotTable } from "../hooks/use-lot-table"

export const INITIAL_LOT_DATA: LotList = {
  id: '',
  number: '',
  description: '',
  createdAt: new Date().toISOString().split('T')[0],
  active: true,
};

export const DEFAULT_TABLE_HEAD: TableColumn[] = [
  { id: "number", label: "Numéro de lot", type: "text" },
  { id: "description", label: "Description", type: "text" },
  { id: "createdAt", label: "Date de création", type: "date" },
  { id: "", label: "Action" },
];

const lotTabsConfig: TabConfig<LotList> = {
  type: TableType.Lot,
  listTitle: "Liste lots",
  newItemTitle: "Nouveau lot",
  initialData: INITIAL_LOT_DATA,
  getItemCode: (lot) => lot.id,
}

export default function LotListView() {

  const {
    tabs,
    activeTab,
    handleTabClose,
    handleTabChange,
    handleTabAdd,
    handleEdit,
    handleView,
    handleCancel,
    handleCopy,
    showConfirmDialog,
    setShowConfirmDialog,
    handleConfirmDialogAction,
    updateTabContent,
  } = useTabsManager<LotList>(lotTabsConfig)

  const {
    table,
    filteredData,
    filters,
    tableHead,
    notFound,
    handleFilterChange,
    handleResetFilters,
    handleResetColumns,
    handleColumnsChange,
    onPageChange,
    page,
    onRowsPerPageChange,
    rowsPerPage,
    totalLots,
    sortBy,
    sortDirection,
  } = useLotTable();

  const activeTabData = useMemo(() => {
    return tabs.find((tab) => tab.id === activeTab)
  }, [tabs, activeTab])

  const renderRow = (row: LotList) => (
    <LotTableRow
      key={row.id}
      dense={table.dense}
      row={row}
      handleEdit={handleEdit}
      handleCopy={handleCopy}
      handleDetails={handleView}
      selected={table.selected.includes(row.id)}
      onSelectRow={() => table.onSelectRow(row.id)}
      columns={tableHead.slice(0, -1)}
      handleOpenConsult={handleView}
    />
  )

  const isList = activeTab === "list"

  return (
    <>
      <Stack
        flexGrow={0}
        direction="row"
        alignItems="center"
        justifyContent="flex-end"
        spacing={{ xs: 0.5, sm: 1 }}
      >
        <TableControlBar
          type={TableType.Lot}
          handleTabAdd={handleTabAdd}
          activeTab={activeTab}
          onResetFilters={handleResetFilters}
          onResetColumns={handleResetColumns}
          onColumnsChange={handleColumnsChange}
          initialColumns={tableHead.slice(0, -1)}
          onFilters={handleFilterChange}
          filteredData={filteredData}
        />
      </Stack>

      <ConditionalComponent isValid={isList}>
        <Typography variant="h5" sx={{ mb: 2, color: "primary.main", fontWeight: "bold" }}>
          Liste Lots
        </Typography>
      </ConditionalComponent>

      <TabsCustom
        type={TableType.Lot}
        tabs={tabs}
        activeTab={activeTab}
        handleTabChange={handleTabChange}
        handleTabClose={handleTabClose}
      />

      <ConditionalComponent
        isValid={isList}
        defaultComponent={
          <LotForm
            lot={activeTabData?.content as LotList}
            onClose={(force) => handleCancel(activeTab, force)}
            mode={activeTabData?.mode || "add"}
            tableHead={tableHead}
            updateTabContent={updateTabContent}
            tabId={activeTab}
            
          />
        }
      >
        <>
          <TableManager
            filteredData={filteredData}
            table={table}
            tableHead={tableHead}
            notFound={notFound}
            filters={filters}
            onFilterChange={handleFilterChange}
            renderRow={renderRow}
            fixedHeight={`calc(100vh - ${HEADER.H_DESKTOP + 195}px)`}
            onPageChange={onPageChange}
            onRowsPerPageChange={onRowsPerPageChange}
            rowsPerPage={rowsPerPage || 20}
            page={page || 0}
            count={totalLots}
            sortBy={sortBy || 'number'}
            sortDirection={sortDirection || 'desc'}
          />
        </>
      </ConditionalComponent>
      <UnsavedChangesDialog
        open={showConfirmDialog}
        onClose={() => setShowConfirmDialog(false)}
        onConfirm={() => handleConfirmDialogAction()}
        onCancel={() => setShowConfirmDialog(false)}
      />
    </>
  )
}

==> vsn-backoffice-front-v0.0.84.zip: vsn-backoffice-front-v0.0.84/src/shared/sections/admin-config/infrastructure/lot/view/lot-list-view.tsx <==
"use client"

import { useMemo } from "react"
import { Stack, Typography } from "@mui/material"
import { HEADER } from "@/layouts/config-layout"
import TableControlBar from "@/shared/components/table/table-control-bar"
import type { LotList } from "@/shared/types/infrastructure"
import { type TabConfig, useTabsManager } from "@/hooks/use-tabs-manager"
import { TableType, TableColumn } from "@/shared/types/common"
import TabsCustom from "@/shared/components/tabs/tabs-custom"
import TableManager from "@/shared/components/table/table-manager"
import LotForm from "./lot-form"
import LotTableRow from "./lot-row"
import ConditionalComponent from "@/shared/components/table/ConditionalComponent"
import { UnsavedChangesDialog } from "@/shared/components/dialog/UnsavedChangesDialog"
import { useLotTable } from "../hooks/use-lot-table"

export const INITIAL_LOT_DATA: LotList = {
  id: '',
  number: '',
  description: '',
  createdAt: new Date().toISOString().split('T')[0],
  active: true,
};

export const DEFAULT_TABLE_HEAD: TableColumn[] = [
  { id: "number", label: "Numéro de lot", type: "text" },
  { id: "description", label: "Description", type: "text" },
  { id: "createdAt", label: "Date de création", type: "date" },
  { id: "", label: "Action" },
];

const lotTabsConfig: TabConfig<LotList> = {
  type: TableType.Lot,
  listTitle: "Liste lots",
  newItemTitle: "Nouveau lot",
  initialData: INITIAL_LOT_DATA,
  getItemCode: (lot) => lot.number,
}

export default function LotListView() {

  const {
    tabs,
    activeTab,
    handleTabClose,
    handleTabChange,
    handleTabAdd,
    handleEdit,
    handleView,
    handleCancel,
    handleCopy,
    showConfirmDialog,
    setShowConfirmDialog,
    handleConfirmDialogAction,
    updateTabContent,
  } = useTabsManager<LotList>(lotTabsConfig)

  const {
    table,
    filteredData,
    filters,
    tableHead,
    notFound,
    handleFilterChange,
    handleResetFilters,
    handleResetColumns,
    handleColumnsChange,
    onPageChange,
    page,
    onRowsPerPageChange,
    rowsPerPage,
    totalLots,
    sortBy,
    sortDirection,
  } = useLotTable();

  const activeTabData = useMemo(() => {
    return tabs.find((tab) => tab.id === activeTab)
  }, [tabs, activeTab])

  const renderRow = (row: LotList) => (
    <LotTableRow
      key={row.id}
      dense={table.dense}
      row={row}
      handleEdit={handleEdit}
      handleCopy={handleCopy}
      handleDetails={handleView}
      selected={table.selected.includes(row.id)}
      onSelectRow={() => table.onSelectRow(row.id)}
      columns={tableHead.slice(0, -1)}
      handleOpenConsult={handleView}
    />
  )

  const isList = activeTab === "list"

  return (
    <>
      <Stack
        flexGrow={0}
        direction="row"
        alignItems="center"
        justifyContent="flex-end"
        spacing={{ xs: 0.5, sm: 1 }}
      >
        <TableControlBar
          type={TableType.Lot}
          handleTabAdd={handleTabAdd}
          activeTab={activeTab}
          onResetFilters={handleResetFilters}
          onResetColumns={handleResetColumns}
          onColumnsChange={handleColumnsChange}
          initialColumns={tableHead.slice(0, -1)}
          onFilters={handleFilterChange}
          filteredData={filteredData}
        />
      </Stack>

      <ConditionalComponent isValid={isList}>
        <Typography variant="h5" sx={{ mb: 2, color: "primary.main", fontWeight: "bold" }}>
          Liste Lots
        </Typography>
      </ConditionalComponent>

      <TabsCustom
        type={TableType.Lot}
        tabs={tabs}
        activeTab={activeTab}
        handleTabChange={handleTabChange}
        handleTabClose={handleTabClose}
      />

      <ConditionalComponent
        isValid={isList}
        defaultComponent={
          <LotForm
            lot={activeTabData?.content as LotList}
            onEdit={handleEdit}
            onClose={(force) => handleCancel(activeTab, force)}
            mode={activeTabData?.mode || "add"}
            tableHead={tableHead}
            updateTabContent={updateTabContent}
            tabId={activeTab}

          />
        }
      >
        <>
          <TableManager
            filteredData={filteredData}
            table={table}
            tableHead={tableHead}
            notFound={notFound}
            filters={filters}
            onFilterChange={handleFilterChange}
            renderRow={renderRow}
            fixedHeight="calc(100vh - 320px)"
            onPageChange={onPageChange}
            onRowsPerPageChange={onRowsPerPageChange}
            rowsPerPage={rowsPerPage || 20}
            page={page || 0}
            count={totalLots}
            sortBy={sortBy || 'id'}
            sortDirection={sortDirection || 'desc'}
          />
        </>
      </ConditionalComponent>
      <UnsavedChangesDialog
        open={showConfirmDialog}
        onClose={() => setShowConfirmDialog(false)}
        onConfirm={() => handleConfirmDialogAction()}
        onCancel={() => setShowConfirmDialog(false)}
      />
    </>
  )
}
